@@ -1,4 +1,5 @@
 from django.contrib import admin
+from django.forms import ModelForm
 from polaris.models import Transaction, Asset
 
 
@@ -15,9 +16,17 @@ class AssetAdmin(admin.ModelAdmin):
     This defines the admin view of an Asset.
     """
 
-    exclude = ("distribution_seed",)
     list_display = "code", "issuer", "deposit_enabled", "withdrawal_enabled"
 
+    def get_fields(self, request, obj=None):
+        fields = super().get_fields(request, obj)
+        if not (
+            request.user.is_superuser
+            or request.user.user_permissions.filter(name="Can edit asset").exists()
+        ):
+            fields.remove("distribution_seed")
+        return fields
+
 
 admin.site.register(Transaction, TransactionAdmin)
 admin.site.register(Asset, AssetAdmin)
